<?php


/**
 * Return the version string.
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return String Version
 */
function sr_plugin_version()
{
    return "0.4.7";
}

/**
 * Convert the $_POST variable into a style hash
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param Object $POST Post object being shown on the page
 * @return Array $style An associative array of styles for The Slide
 */
function create_style_hash($POST)
{
    $style = array();

    // Iterate over our $_POST var and rip out the styles to put into a hash
    foreach ($POST as $name => $value) {
        if (!preg_match('/^srslide_style_(.+?)_(.+?)$/',$name,$style_name)) { continue; }
        $style[$style_name[1]][$style_name[2]] = $value;
    }

    return clean_style_options($style);
}

/**
 * Remove the extra style options prior to save/send to SimpleReach
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param Array $style The associative array of styles for The Slide
 * @return Array $style The clean associative array of styles for The Slide
 */
function clean_style_options($style)
{
    // Remove the link_color_text and just have link_color
    if ($style['link']['color'] == 'other') {
        $style['link']['color'] = check_hash($style['link']['color_text']);
    }
    unset($style['link']['color_text']);

    return $style;
}

/**
 * Add the leading '#' to a string if it doesn't exist
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param String $value Any string
 * @return String $value String with the '#' added
 */
function check_hash($val)
{
    if (preg_match('/^#/',$val)) {
        return $val;
    } else {
        return "#{$val}";
    }
}


/**
 * Put together some debug info to send to SimpleReach when support
 * is requested.
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return String Debug info
 */
function create_debug_info()
{
    $rv = "";
    $rv .= "PID: ".get_option('srslide_pid')."\n";
    $rv .= "Email: ".get_option('srslide_sr_login')."\n";
    $rv .= "Website: ".get_option('siteurl')."\n";
    $rv .= "Account: ".get_option('blogname')."\n";
    $rv .= "WP Version: ".get_bloginfo('version')."\n";
    $rv .= "Plugin Version: ".sr_plugin_version()."\n\n";

    return $rv;
}

/**
 * Return the SimpleReach title for the post.
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param Object $post Post object being shown on the page
 * @return String Title of the post with slashes escaped
 */
function get_sr_post_title($post)
{
    $title = get_post_meta($post->ID,'_srslide_title',true);

    if (!isset($title) || empty($title)) {
        $title = $post->post_title;
    }

    return addslashes($title);
}


/**
 * Return the SimpleReach tags for the post.
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param Object $post Post object being shown on the page
 * @return String Tags of the post with slashes escaped
 */
function get_sr_post_tags($post)
{
    $tags = get_post_meta($post->ID,'_srslide_tags',true);

    if (!isset($tags) || empty($tags)) {
        $wptags = wp_get_post_tags($post->ID);
        foreach ($wptags as $tag) {
            $tags .= $tag->name . ",";
        }
        $tags = rtrim($tags,",");
    }

    return addslashes($tags);
}


/**
 * Set some defaults for the plugin
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param Object $post_data The result of the $_POST data from the registration
 * @return None
 */
function set_srslide_defaults($post_data)
{
    update_option('srslide_sr_login',$post_data['srslide_sr_login']);
    update_option('srslide_sr_pass',$post_data['srslide_sr_pass']);
    update_option('srslide_registered',true);
    ($post_data['srslide_show_logo'] == 'on') ? update_option('srslide_show_logo',true) : update_option('srslide_show_logo',false);

    update_option('srslide_header_text','RECOMMENDED FOR YOU');

    $style_defaults = array(
        'element' => array(
            'bottom' => '0px'
        ),
        'link' => array(
            'color' => 'FE3F10'
        )
    );
    update_option('srslide_styles',$style_defaults);
}


/**
 * Update The Slide styles on the SimpleReach site
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param Array $styles Style to be converted to JSON
 * @return String OK or error string
 */
function update_slide_styles()
{
    // Pull all the necessary options
    $srpid = get_option('srslide_pid');
    $srlogin = get_option('srslide_sr_login');
    $srapi_key = get_option('srslide_api_key');
    $srslide_style = get_option('srslide_styles');

    // Setup our POST parameters
    $encoded_params = 'ts='.(int)gmdate('U').'&';
    $encoded_params .= "pid=".urlencode($srpid)."&";
    $encoded_params .= "login=".urlencode($srlogin)."&";

    // Handle if the user's API key isn't saved in WP
    if (strlen($srapi_key) != 32) {
      $encoded_params .= "pass=".urlencode(get_option('srslide_sr_pass'))."&";
    } else {
      $encoded_params .= "api_key=".urlencode($srapi_key)."&";
    }

    // Add the styles to the POST
    $style_array = array('style' => get_option('srslide_styles'));
    $encoded_params .= http_build_query($style_array);

    // Curl call for registration
    $curl = curl_init();
    curl_setopt($curl, CURLOPT_URL, "https://www.simplereach.com/publisher/generate_slide_css");
    curl_setopt($curl, CURLOPT_POST, count(explode('&',$encoded_params)));
    curl_setopt($curl, CURLOPT_POSTFIELDS, $encoded_params);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
    $curl_resp = curl_exec($curl);
    curl_close($curl);

    // Decode the JSON
    $resp = json_decode($curl_resp);

    if ($resp->{'success'}) {
        return "OK";
    } else {
        if ($resp->{'error'} == 'Incorrect Timestamp') {
            return "There was an error while you were attempting to register. Please try again or contact <a href='mailto:support@simplereach.com'>SimpleReach support</a> if you believe you have received this message in error.";
        } else if ($resp->{'error'} == 'Invalid Password') {
            return "The user name that you are attempting to register with already exists, but the password you entered was incorrect. Please try again or contact <a href='mailto:support@simplereach.com'>SimpleReach support</a> if you believe you have received this message in error.";
        } else {
            // We should never get here
            return "There was an error contacting SimpleReach. Please try saving your options again.";
        }
    }

    // We should never get here either
    return "There was an error contacting SimpleReach. Please try your re-saving your options.";
}


?>
